﻿using FreeSql.DatabaseModel;using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Threading.Tasks;
using Newtonsoft.Json;
using FreeSql.DataAnnotations;

namespace FuelServer.Core.Entity
{

	/// <summary>
	/// 订单表
	/// </summary>
	[JsonObject(MemberSerialization.OptIn), Table(DisableSyncStructure = true)]
	public partial class transactions {

		/// <summary>
		/// 订单唯一标识符
		/// </summary>
		[JsonProperty, Column(IsPrimary = true, IsIdentity = true)]
		public int Id { get; set; }

		/// <summary>
		/// 油站唯一标识符
		/// </summary>
		[JsonProperty]
		public Guid Buid { get; set; }

		/// <summary>
		/// 用户ID
		/// </summary>
		[JsonProperty]
		public int MiniProgramID { get; set; }

		/// <summary>
		/// 枪号
		/// </summary>
		[JsonProperty]
		public int NozzleId { get; set; }

		/// <summary>
		/// 油品ID
		/// </summary>
		[JsonProperty]
		public int ProductId { get; set; }

		/// <summary>
		/// 实际支付金额
		/// </summary>
		[JsonProperty]
		public decimal ActualPaymentAmount { get; set; }

		/// <summary>
		/// 授权时间
		/// </summary>
		[JsonProperty, Column(DbType = "timestamp", InsertValueSql = "0000-00-00 00:00:00")]
		public DateTime AuthorizationTime { get; set; }

		[JsonProperty, Column(StringLength = 100)]
		public string CreateBy { get; set; }

		[JsonProperty, Column(DbType = "timestamp", InsertValueSql = "0000-00-00 00:00:00")]
		public DateTime CreateTime { get; set; }

		/// <summary>
		/// 挂枪时间
		/// </summary>
		[JsonProperty, Column(DbType = "timestamp", InsertValueSql = "CURRENT_TIMESTAMP")]
		public DateTime FuelItemTransactionEndTime { get; set; }

		/// <summary>
		/// 是否删除
		/// </summary>
		[JsonProperty, Column(DbType = "tinyint(1)")]
		public sbyte? IsDeleted { get; set; } = 0;

		/// <summary>
		/// 订单状态
		/// </summary>
		[JsonProperty]
		public transactionsORDERSTATUS OrderStatus { get; set; }

		/// <summary>
		/// 订单类型
		/// </summary>
		[JsonProperty]
		public transactionsORDERTYPE OrderType { get; set; }

		/// <summary>
		/// 原金额
		/// </summary>
		[JsonProperty]
		public decimal OriginalAmount { get; set; }

		/// <summary>
		/// 支付方式
		/// </summary>
		[JsonProperty, Column(StringLength = 50)]
		public string PaymentMethod { get; set; }

		/// <summary>
		/// 油品名称
		/// </summary>
		[JsonProperty, Column(StringLength = 100, IsNullable = false)]
		public string ProductName { get; set; }

		/// <summary>
		/// 升数
		/// </summary>
		[JsonProperty]
		public decimal Qty { get; set; }

		/// <summary>
		/// 退款金额
		/// </summary>
		[JsonProperty]
		public decimal? RefundAmount { get; set; }

		/// <summary>
		/// 订单流水号
		/// </summary>
		[JsonProperty, Column(StringLength = 50, IsNullable = false)]
		public string TransactionNumber { get; set; }

		/// <summary>
		/// 交易时间
		/// </summary>
		[JsonProperty, Column(DbType = "timestamp", InsertValueSql = "0000-00-00 00:00:00")]
		public DateTime TransactionTime { get; set; }

	}

	public enum transactionsORDERSTATUS {
		未支付 = 1, 已支付, 支付中, 退全款, 退余额, 卡支付
	}
	public enum transactionsORDERTYPE {
		预支付 = 1, 后支付
	}
}
